appname

package module
v0.0.0-...-c340b46 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2017 License: MIT Imports: 3 Imported by: 2

README

appname

returns name of the running app, excluding the .exe extension if it exists.

This is a very simple package to get the name of the executable. For Go applications built on Windows, the executable will end with .exe. This returns the app name w/o the .exe suffix, if it exists.

Documentation

Overview

Package appname returns the current executable's name. If the name ends with a .exe suffix, it is elided.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get() string

Types

This section is empty.

Jump to